"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DoorsDoorOpenEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a door is opened either by a player opening it manually, i.e.
 * the doors on Polus, or opened automatically after some time, i.e. the doors
 * on The Skeld.
 */
class DoorsDoorOpenEvent extends events_1.RevertableEvent {
    constructor(room, doorsystem, message, 
    /**
     * The player that opened the door. Only available if the client is the
     * host.
     */
    player, 
    /**
     * The door that the player opened.
     */
    door) {
        super();
        this.room = room;
        this.doorsystem = doorsystem;
        this.message = message;
        this.player = player;
        this.door = door;
        this.eventName = "doors.open";
        this._alteredDoor = door;
    }
    /**
     * The alternate door that will be opened, if changed.
     */
    get alteredDoor() {
        return this._alteredDoor;
    }
    /**
     * Change the door that was opened.
     * @param door The door to open.
     */
    setDoor(door) {
        if (typeof door === "number") {
            return this.setDoor(this.doorsystem.doors[door]);
        }
        this._alteredDoor = door;
    }
}
exports.DoorsDoorOpenEvent = DoorsDoorOpenEvent;
DoorsDoorOpenEvent.eventName = "doors.open";
//# sourceMappingURL=Open.js.map