import { BasicEvent } from "@skeldjs/events";
import { SetVisorMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { ProtocolEvent } from "../ProtocolEvent";
import { PlayerEvent } from "./PlayerEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
/**
 * Emitted when a player has their player visor updated.
 */
export declare class PlayerSetVisorEvent<RoomType extends Hostable = Hostable> extends BasicEvent implements RoomEvent, PlayerEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly player: PlayerData<RoomType>;
    readonly message: SetVisorMessage | undefined;
    /**
     * The visor that the player had before.
     */
    readonly oldVisorId: string;
    /**
     * The new visor that the player has.
     */
    readonly newVisorId: string;
    static eventName: "player.setvisor";
    eventName: "player.setvisor";
    private _alteredVisorId;
    constructor(room: RoomType, player: PlayerData<RoomType>, message: SetVisorMessage | undefined, 
    /**
     * The visor that the player had before.
     */
    oldVisorId: string, 
    /**
     * The new visor that the player has.
     */
    newVisorId: string);
    /**
     * The altered visor that the player will have set instead, if changed.
     */
    get alteredVisorId(): string;
    /**
     * Revert the player's visor back to their old visor.
     */
    revert(): void;
    /**
     * Change the visor that the player had set.
     * @param visor The visor to set.
     */
    setVisor(visor: string): void;
}
//# sourceMappingURL=SetVisor.d.ts.map