import { HazelReader, HazelWriter } from "@skeldjs/util";
import { SystemType } from "@skeldjs/constant";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { ExtractEventTypes } from "@skeldjs/events";
import { InnerShipStatus } from "../objects";
import { SystemStatus } from "./SystemStatus";
import { PlayerData } from "../PlayerData";
import { O2ConsolesClearEvent, O2ConsolesCompleteEvent } from "../events";
import { SystemStatusEvents } from "./events";
import { Hostable } from "../Hostable";
export interface LifeSuppSystemData {
    timer: number;
    completed: Set<number>;
}
export declare type LifeSuppSystemEvents<RoomType extends Hostable = Hostable> = SystemStatusEvents<RoomType> & ExtractEventTypes<[
    O2ConsolesClearEvent<RoomType>,
    O2ConsolesCompleteEvent<RoomType>
]>;
/**
 * Represents a system responsible for handling oxygen consoles.
 *
 * See {@link LifeSuppSystemEvents} for events to listen to.
 */
export declare class LifeSuppSystem<RoomType extends Hostable = Hostable> extends SystemStatus<LifeSuppSystemData, LifeSuppSystemEvents, RoomType> implements LifeSuppSystemData {
    private lastUpdate;
    /**
     * The timer until oxygen runs out.
     */
    timer: number;
    /**
     * The completed consoles.
     */
    completed: Set<number>;
    constructor(ship: InnerShipStatus<RoomType>, systemType: SystemType, data?: HazelReader | LifeSuppSystemData);
    get sabotaged(): boolean;
    Deserialize(reader: HazelReader, spawn: boolean): void;
    Serialize(writer: HazelWriter, spawn: boolean): void;
    HandleSabotage(player: PlayerData<RoomType> | undefined, rpc: RepairSystemMessage | undefined): Promise<void>;
    private _clearConsoles;
    /**
     * Clear the completed consoles. This is a host operation on official servers.
     */
    clearConsoles(): Promise<void>;
    private _completeConsole;
    /**
     * Mark a console as being complete.
     * @param consoleId The ID of the console to mark as complete.
     */
    completeConsole(consoleId: number): Promise<void>;
    private _repair;
    repair(): Promise<void>;
    HandleRepair(player: PlayerData<RoomType> | undefined, amount: number, rpc: RepairSystemMessage | undefined): Promise<void>;
    Detoriorate(delta: number): void;
}
//# sourceMappingURL=LifeSuppSystem.d.ts.map